@@ -123,12 +123,12 @@ sub LoadByCols {
 # Args    : see DBIx::SearchBuilder::Record::_Set
 # Lvalue  : ?
 
-sub _Set () { 
+sub __Set () { 
   my ($this, %attr) = @_; 
 
   $this->_expire( $this->_gen_primary_cache_key());
  
-  return $this->SUPER::_Set(%attr);
+  return $this->SUPER::__Set(%attr);
 
 }
 
@@ -160,16 +160,17 @@ sub Delete () {
 
 sub _gc_expired () { 
   my ($this) = @_; 
-  
+ 
+  my $time = time(); 
   foreach my $cache_key (keys %{$this->_KeyCache}) {
     my $cache_time = $this->_RecordCache->{$cache_key}{'time'} || 0;  
     $this->_expire($cache_key) 
-      if ((time() - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
+      if (($time - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
   }
   foreach my $cache_key (keys %{$this->_RecordCache}) {
     my $cache_time = $this->_RecordCache->{$cache_key}{'time'} || 0 ;  
     $this->_expire($cache_key) 
-      if ((time() - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
+      if (($time - $cache_time) > $this->{'_CacheConfig'}{'cache_for_sec'});
   }
 }
 
@@ -281,6 +282,9 @@ sub _fetch_cache_key {
 sub _gen_primary_cache_key {
     my ($this) = @_;
 
+
+    return undef unless ($this->Id);
+
     my $primary_cache_key = $this->Table() . ':';
     foreach my $key (@{$this->_PrimaryKeys}) {
         $primary_cache_key .= $key.'='.
